@@ -3,7 +3,7 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
   library(raster); on.exit(detach("package:raster"), add = TRUE)
 
   owd <- getwd()
-  tmpdir <- file.path(tempdir(), "splitRaster-test") %>% reproducible::checkPath(create = TRUE)
+  tmpdir <- file.path(tempdir(), "splitRaster-test") %>% checkPath(create = TRUE)
   setwd(tmpdir)
 
   on.exit({
@@ -166,7 +166,7 @@ test_that("splitRaster works in parallel", {
     library(raster); on.exit(detach("package:raster"), add = TRUE)
 
     tmpdir <- file.path(tempdir(), "splitRaster-test-parallel") %>%
-      reproducible::checkPath(create = TRUE)
+      checkPath(create = TRUE)
 
     on.exit({
       #detach("package:raster")
@@ -227,7 +227,7 @@ test_that("splitRaster and mergeRaster work on large on-disk rasters", {
   skip_on_appveyor()
   skip("This is very big.")
 
-  tmpdir <- file.path(tempdir(), "splitRaster-test-large") %>% reproducible::checkPath(create = TRUE)
+  tmpdir <- file.path(tempdir(), "splitRaster-test-large") %>% checkPath(create = TRUE)
   library(magrittr)
   library(raster); on.exit(detach("package:raster"), add = TRUE)
 
